Ansys Sphinx theme
==================
|ansys| |python| |pypi| |GH-CI| |MIT| |black|

.. |ansys| image:: https://img.shields.io/badge/Ansys-ffc107.svg?logo=data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAIAAACQkWg2AAABDklEQVQ4jWNgoDfg5mD8vE7q/3bpVyskbW0sMRUwofHD7Dh5OBkZGBgW7/3W2tZpa2tLQEOyOzeEsfumlK2tbVpaGj4N6jIs1lpsDAwMJ278sveMY2BgCA0NFRISwqkhyQ1q/Nyd3zg4OBgYGNjZ2ePi4rB5loGBhZnhxTLJ/9ulv26Q4uVk1NXV/f///////69du4Zdg78lx//t0v+3S88rFISInD59GqIH2esIJ8G9O2/XVwhjzpw5EAam1xkkBJn/bJX+v1365hxxuCAfH9+3b9/+////48cPuNehNsS7cDEzMTAwMMzb+Q2u4dOnT2vWrMHu9ZtzxP9vl/69RVpCkBlZ3N7enoDXBwEAAA+YYitOilMVAAAAAElFTkSuQmCC
   :target: https://github.com/ansys
   :alt: Ansys

.. |python| image:: https://img.shields.io/pypi/pyversions/ansys_sphinx_theme?logo=pypi
   :target: https://pypi.org/project/ansys-sphinx-theme/
   :alt: Python

.. |pypi| image:: https://img.shields.io/pypi/v/ansys-sphinx-theme.svg?logo=python&logoColor=white
   :target: https://pypi.org/project/ansys-sphinx-theme
   :alt: PyPI

.. |GH-CI| image:: https://github.com/ansys/ansys-sphinx-theme/actions/workflows/ci_cd.yml/badge.svg
   :target: https://github.com/ansys/ansys-sphinx-theme/actions/workflows/ci_cd.yml
   :alt: GH-CI

.. |MIT| image:: https://img.shields.io/badge/License-MIT-yellow.svg
   :target: https://opensource.org/licenses/MIT
   :alt: MIT

.. |black| image:: https://img.shields.io/badge/code_style-black-000000.svg?style=flat
   :target: https://github.com/psf/black
   :alt: Black

.. |Downloads| image:: https://img.shields.io/pypi/dm/ansys-sphinx-theme.svg?label=PyPI%20downloads
   :target: https://pypi.org/project/ansys-sphinx-theme
   :alt: Downloads


Introduction
------------
The Ansys Sphinx theme is an extension of the popular
`PyData Sphinx theme <https://github.com/pydata/pydata-sphinx-theme>`_
that is used by `numpy <https://numpy.org/doc/stable/>`_,
`pandas <https://pandas.pydata.org/docs/>`_,
`pyvista <https://docs.pyvista.org>`_, and many more
scientific Python packages.

You use the Ansys Sphinx theme with `Sphinx <https://www.sphinx-doc.org/en/master/>`_,
a Python documentation generator, to create documentation.
The theme's objective is to ensure that Ansys documentation
looks and behaves consistently.

While this theme is primarily used to create documentation
for PyAnsys libraries, you can also use it to create
documentation for any Ansys project with content in
reStructuredText (RST) and Markdown (files).

If you are new to using Sphinx, see `Sphinx Getting Started
<https://www.sphinx-doc.org/en/master/usage/quickstart.html>`_.

Documentation and issues
~~~~~~~~~~~~~~~~~~~~~~~~
Documentation for the latest stabe release of Ansys Sphinx theme is hosted at
`Ansys Sphinx Theme documentation <https://sphinxdocs.ansys.com>`_.

The documentation has these sections:

- `Getting started <https://sphinxdocs.ansys.com/version/stable/getting_started.html>`_ : Learn
  how to install the theme and use it in your Sphinx project.
- `User guide <https://sphinxdocs.ansys.com/version/stable/user_guide.html>`_ : Learn how to
  customize the theme and use its features.
- `Examples <https://sphinxdocs.ansys.com/version/stable/examples.html>`_ : See examples of
  Sphinx components and how it renders with the Ansys Sphinx theme.
- `Release notes <https://sphinxdocs.ansys.com/version/stable/changelog.html>`_ : See the
  changes in each release of the theme.

On the `Issues page <https://github.com/ansys/ansys-sphinx-theme/issues>`_
for this repository, you can create issues to submit questions, report bugs,
and request new features. To reach the PyAnsys support team, email
`pyansys.core@ansys.com <pyansys.core@ansys.com>`_.

License
~~~~~~~
This theme is licensed under the `MIT License
<https://raw.githubusercontent.com/ansys/ansys-sphinx-theme/main/LICENSE>`_.
